
class ResourceExists(Exception):
    pass


class ResourceNotFound(Exception):
    pass


class Unauthorized(Exception):
    pass


class ServerInternalError(Exception):
    pass


class ServerConnectionError(Exception):
    pass


import json
from rmbcommon.models.base import BaseCoreModel

class BIQuestion:

    def __init__(self, content):
        self.content = content

    def __str__(self):
        return self.content

class BIQueryPlan:
    pass


class NaturalQuery:

    def __init__(self, content: str):
        self.content = content

    def __str__(self):
        return self.content


class StrucQuery:
    pass

    def __init__(self, content: str):
        self.content = content

    def __str__(self):
        return self.content

    def __repr__(self):
        return self.__str__()


class QueryResult:

    def __init__(self, content: any):
        self.content = content

    def __str__(self):
        raise NotImplementedError

    def __repr__(self):
        return self.__str__()


class BIAnswer(BaseCoreModel):
    __init_dict_keys__ = ['status', 'elapsed_time', 'answer', 'structure_queries']

    def __str__(self):
        return f"[{self.status}-{self.elapsed_time}s] {self.answer}"

    def __repr__(self):
        return self.__str__()




import os
import requests
from requests.exceptions import ConnectionError
from rmbclient.log import log

from rmbclient.exceptions import ResourceExists, Unauthorized, ResourceNotFound, ServerInternalError, ServerConnectionError


class APIRequest:
    ## TODO: 添加异常处理
    token = ""
    api_url = "http://127.0.0.1:500"
    debug = False

    def _handle_request(self, method, url, headers, json=None):
        if method in ('GET', 'DELETE'):
            response = requests.get(url, headers=headers)
        elif method == 'POST':
            response = requests.post(url, headers=headers, json=json)
        else:
            raise ValueError("Unsupported HTTP method")
        return response

    def send(self, endpoint, method, data=None) -> dict or None:

        headers = {"Authorization": f"Bearer {self.token}"}
        url = f"{self.api_url}{endpoint}"

        try:
            response = self._handle_request(method, url, headers, json=data)
        except ConnectionError:
            raise ServerConnectionError(f"Server {url} Connection Error")

        if response.status_code in (200, 201):
            if method == 'DELETE':
                return True
            else:
                return response.json()

        try:
            _res = response.json()
        except Exception:
            _res = str(response)

        log_record = {'response': _res, 'method': method, 'endpoint': endpoint, 'data': data}

        if response.status_code == 409:
            raise ResourceExists("Resource already exists")
        elif response.status_code == 401:
            raise Unauthorized("Unauthorized")
        elif response.status_code in (404, 403):
            raise ResourceNotFound(f"Resource not found: {log_record}")
        elif response.status_code == 500:
            raise ServerInternalError(f"Server Internal Error: {log_record}")
        elif response.status_code == 400:
            raise ValueError(f"Bad Request: {log_record}")
        else:
            raise Exception(f"Error: {log_record}")


rmb_api = APIRequest()



import uuid
import base62
import time
from datetime import datetime


def format_time_ago(unix_timestamp) -> str:
    """
    Convert a Unix timestamp to a user-friendly time string.
    """
    now = int(time.time())
    diff = now - unix_timestamp

    # Time calculations
    minute = 60
    hour = 60 * minute
    day = 24 * hour

    if diff < hour:
        return f"{diff // minute} minutes ago" if diff >= minute else "Just now"
    elif diff < day:
        hours = diff // hour
        minutes = (diff % hour) // minute
        return f"{hours} hours {minutes} minutes ago" if minutes else f"{hours} hours ago"
    elif diff < 3 * day:
        return f"{diff // day} days ago"
    else:
        # Convert to specific date and time format for durations longer than 3 days
        return datetime.utcfromtimestamp(unix_timestamp).strftime('%Y%m%d %H:%M:%S')

def gen_base62_uuid():
    # 生成一个 UUID
    my_uuid = uuid.uuid4()
    # 转换 UUID 的整数表示为 Base62
    base62_uuid = base62.encode(int(my_uuid))
    return base62_uuid


def gen_uuid_for_vector():
    return str(uuid.uuid1())


def gen_id_for_graph():
    return f"ds_{gen_base62_uuid()}"


def gen_id_for_chat():
    return f"chat_{gen_base62_uuid()}"


def gen_id_for_msg():
    return f"msg_{gen_base62_uuid()}"


def gen_id_for_run():
    return f"run_{gen_base62_uuid()}"





# 通用的数据源类，提供了各种数据源均需要的基本属性和方法，比如Original MetaData以及获取MetaData的方法
from rmbcommon.models.base import BaseCoreModel


class DataSourceCore(BaseCoreModel):

    __init_dict_keys__ = ['id', 'name', 'type', 'access_config']

    def __repr__(self):
        if self.id:
            return f"<{self.id}: {self.name} >"
        else:
            return f"<{self.type}: {self.name} (not saved)>"
    #
    # @property
    # def schemas(self):
    #     # 数据源的所有schema
    #     meta = self.accessor.retrieve_meta_data()
    #     return meta.schemas

    @property
    def safe_access_config(self):
        # TODO: 保护敏感信息
        return self.access_config

    # @property
    # def accessor(self):
    #     # 数据源的数据访问器
    #     return create_data_accessor(
    #         self.type,
    #         ds_name=self.name,
    #         ds_access_config=self.access_config
    #     )
    #



from rmbclient.rmb import ReliableMetaBrain as RMB
import unittest
from rmbclient.log import log


class TestChat(unittest.TestCase):
    data = RMB(token="token1", debug=True)

    def test_chat(self):
        datasource_ids = [ds.id for ds in self.data.datasources]

        # 注册数据源
        chat = self.data.chats.create(datasource_ids)
        log.info(f"获取刚刚创建的对话: {self.data.chats.get(chat.id)}")

        log.info(f"获取所有对话: {self.data.chats.to_dict()}")

        # 查询对话

        log.info(f"向 {chat} 中发送消息1: {chat.messages.create('你好')}")
        log.info(f"向 {chat} 中发送消息2: {chat.messages.create('我是张三')}")
        log.info(f"{chat} 中的所有消息: {chat.messages.to_dict()}")

        log.info(f"{chat} 开始运行AI回复消息...")
        run = chat.runs.create()
        log.debug(f"{chat} 运行完成")
        log.info(f"查看AI运行状态 {chat}: {chat.runs.get(run.id)}")

        chat.answer('我是张三吗？')
        chat.answer('我叫什么')
        assert len(chat.messages.to_dict()) == 6

        # 删除对话
        chat.delete()




from rmbcommon.models import (MessageCore)
from rmbclient.models.base import convert_to_object, BaseResourceList
from rmbclient.api import rmb_api


class MessageClientModel(MessageCore):
    pass


class MessageList(BaseResourceList):
    @convert_to_object(cls=MessageClientModel)
    def _get_all_resources(self):
        # 获取所有资源
        return rmb_api.send(endpoint=self.endpoint, method="GET")

    @convert_to_object(cls=MessageClientModel)
    def get(self, id):
        # 通过ID来获取
        return rmb_api.send(endpoint=f"{self.endpoint}/{id}", method="GET")

    @convert_to_object(cls=MessageClientModel)
    def create(self, content):
        # 发送消息
        data = {"content": content}
        return rmb_api.send(endpoint=f"{self.endpoint}", method="POST", data=data)




from rmbclient.rmb import ReliableMetaBrain as RMB
from rmbclient.api import ResourceNotFound
from unittest import TestCase
from rmbclient.log import log


class TestMeta(TestCase):
    # 初始化 Meta Brain 实例
    data = RMB(token="token1", debug=True)  # 使用有效的测试Token

    def _create(self):
        # 注册数据源
        ds = self.data.datasources.register(
            ds_type="MySQL", ds_name="我的MySQL库",
            # ds_access_config={
            #     "host": "fbi.chat",
            #     "port": 3306,
            #     "user": "root",
            #     "password": "Pass1234"
            # })
            ds_access_config={
                "host": "localhost",
                "port": 3306,
                "user": "root",
                "password": ""
            })
        return ds

    def _get_or_create_ds(self):
        name = "我的MySQL库"
        try:
            ds = self.data.datasources.get(name=name)
            log.info(f"datasource {name} found")
        except ResourceNotFound:
            ds = self._create()
            log.info(f"datasource {name} created")
        return ds

    def test_sync_meta(self):
        # 获取数据源
        ds = self._get_or_create_ds()
        runtime_meta = ds.meta.get('runtime')
        print(runtime_meta.to_string())

        ds_copy = self.data.datasources.get(id=ds.id)
        ds_copy_id = ds_copy.id
        ds_list = self.data.datasources
        log.info(f"metadata in runtime: {ds.meta.get('runtime').to_dict()}")
        log.info(f"metadata in brain: {ds.meta.get('in_brain')}")
        ds.meta.sync()
        log.info(f"metadata in brain: {ds.meta.get('in_brain').to_string()}")
        schema_list = ds.meta.get('in_brain').schemas
        log.info(f"schemas: {schema_list}")
        # ds.delete()



from tabulate import tabulate
from rmbclient.log import log


def convert_to_object(cls):
    # 将JSON对象转换为Model对象
    def decorator(func):
        def wrapper(*args, **kwargs):
            json_or_list_data = func(*args, **kwargs)
            # 如果返回的是JSON or List对象
            if isinstance(json_or_list_data, list):
                return [cls.load_from_dict(json_data) for json_data in json_or_list_data]
            elif isinstance(json_or_list_data, dict):
                return cls.load_from_dict(json_or_list_data)
            else:
                log.error(f"Unsupported data type: {type(json_or_list_data)}")
                raise ValueError("Unsupported data type")

        return wrapper

    return decorator


class BaseResourceList:
    def __init__(self, endpoint: str):
        self.endpoint = endpoint

    def __iter__(self):
        # 实现迭代器协议，允许直接迭代资源列表
        self._current = 0
        self._resources = self._get_all_resources() or []
        return self

    def __next__(self):
        if self._current >= len(self._resources):
            raise StopIteration
        resource = self._resources[self._current]
        self._current += 1
        return resource

    def _get_all_resources(self):
        raise NotImplementedError

    def to_dict(self):
        return [resource.to_dict() for resource in self]

    def __repr__(self):
        # 将资源转换为字典列表
        resources_dicts = [resource.to_dict() for resource in self]

        # 使用 tabulate 来生成表格格式的字符串
        return tabulate(resources_dicts, headers="keys", tablefmt="plain")



from rmbclient.resources import ReliableMetaBrain as RMB
from unittest import TestCase
from rmbclient.log import log

class TestDataResource(TestCase):
    def test_clear(self):

        # 初始化 IntelligentDataCortex 实例
        data = RMB(token="token1", debug=True)
        for ds in data.datasources:
            log.debug(f"删除数据源:  {ds}")
            ds.delete()

        data.test_clear_all()



from rmbcommon.models import DataSourceCore, MetaData
from rmbclient.models.base import convert_to_object, BaseResourceList
from rmbclient.api import rmb_api
from rmbclient.exceptions import ResourceNotFound


class MetaDataClientModel:
    def __init__(self, datasource_id):
        self.datasource_id = datasource_id

    def get(self, from_where):
        if from_where not in ["runtime", "in_brain"]:
            raise ValueError("from_where must be one of runtime/in_brain")
        return MetaData.load_from_dict(
            rmb_api.send(
                endpoint=f"/datasources/{self.datasource_id}/meta/{from_where}",
                method="GET"
            )
        )

    def sync(self):
        return rmb_api.send(endpoint=f"/datasources/{self.datasource_id}/meta", method="POST")


class DataSourceClientModel(DataSourceCore):
    @property
    def meta(self) -> MetaDataClientModel:
        return MetaDataClientModel(self.id)

    def delete(self):
        return rmb_api.send(endpoint=f"/datasources/{self.id}", method="DELETE")


class DataResourceList(BaseResourceList):
    @convert_to_object(cls=DataSourceClientModel)
    def _get_all_resources(self):
        # 获取所有资源
        return rmb_api.send(endpoint=self.endpoint, method="GET")

    @convert_to_object(cls=DataSourceClientModel)
    def get(self, id=None, name=None):
        if name:
            ds_list = rmb_api.send(endpoint=f"{self.endpoint}?name={name}", method="GET")
            if ds_list:
                return ds_list[0]
            else:
                raise ResourceNotFound(f"Data Source {name} not found")

        if not id:
            raise ValueError("No ID or Name provided")
        # 通过资源ID来获取
        return rmb_api.send(endpoint=f"{self.endpoint}{id}", method="GET")

    @convert_to_object(cls=DataSourceClientModel)
    def register(self, ds_type, ds_name, ds_access_config):
        data = {
            "type": ds_type, "name": ds_name,
            "access_config": ds_access_config
        }
        return rmb_api.send(endpoint=self.endpoint, method="POST", data=data)








from rmbcommon.models import RunCore
from rmbclient.models.base import convert_to_object, BaseResourceList
from rmbclient.api import rmb_api


class RunClientModel(RunCore):

    def cancel(self):
        return rmb_api.send(
            endpoint=f"/chats/{self.chat_id}/runs/{self.id}",
            method="POST",
            data={"action": "cancel"}
        )


class RunList(BaseResourceList):
    @convert_to_object(cls=RunClientModel)
    def _get_all_resources(self):
        # 获取所有资源
        return rmb_api.send(endpoint=self.endpoint, method="GET")

    @convert_to_object(cls=RunClientModel)
    def get(self, id):
        # 通过ID来获取
        return rmb_api.send(endpoint=f"{self.endpoint}/{id}", method="GET")

    @convert_to_object(cls=RunClientModel)
    def create(self):
        # 运行AI生成回复
        return rmb_api.send(endpoint=f"{self.endpoint}", method="POST")



from functools import wraps
import json
from tabulate import tabulate


def json_to_string(func):
    # 将函数返回的JSON dict对象转换为字符串
    @wraps(func)
    def wrapper(*args, **kwargs):
        result = func(*args, **kwargs)
        return json.dumps(result, indent=4, ensure_ascii=False)
    return wrapper


class DataBaseObject:
    _save_in_db_properties = []

    @property
    def db_properties(self):
        return {k: v for k, v in self.__dict__.items()
                if k in self._save_in_db_properties}

    def to_dict(self):
        raise NotImplementedError

    def to_dict_for_llm(self):
        raise NotImplementedError

    @json_to_string
    def to_string(self):
        return self.to_dict()

    @json_to_string
    def to_string_for_llm(self):
        return self.to_dict_for_llm()

    def __str__(self):
        return self.to_string()


class DataField(DataBaseObject):

    _save_in_db_properties = ['name', 'full_name', 'origin_desc',
                              'curr_desc', 'curr_desc_stat']

    def __init__(self, name, table, origin_desc=None, curr_desc=None,
                 curr_desc_stat=None, related_field=None, **kwargs):
        self.name = name
        self.origin_desc = origin_desc
        self.table = table  # Reference to the DataTable
        self.full_name = f"{self.table.schema.name}.{self.table.name}.{self.name}"
        if curr_desc:
            self.curr_desc = curr_desc
            self.curr_desc_stat = curr_desc_stat
        else:
            self.curr_desc = origin_desc
            self.curr_desc_stat = 'origin'
        self.related_field = related_field  # Reference to related DataField, if any

    def set_related_field(self, field):
        self.related_field = field

    def __repr__(self):
        return f"<DataField(name='{self.full_name}', curr_desc='{self.curr_desc}')>"

    def to_dict(self):
        result = {
            'name': self.name,
            'origin_desc': self.origin_desc,
            'curr_desc': self.curr_desc
        }
        if self.related_field:
            result['related_field'] = self.related_field.full_name
        return result

    def to_dict_for_llm(self):
        result = {
            'name': self.name,
            'curr_desc': self.curr_desc,
        }
        if self.related_field:
            result['related_field'] = self.related_field.full_name
        return result


class DataTable(DataBaseObject):

    _save_in_db_properties = ['name', 'full_name', 'origin_desc',
                              'curr_desc', 'curr_desc_stat']

    def __init__(self, name, schema, origin_desc=None,
                 curr_desc=None, curr_desc_stat=None, **kwargs):
        self.name = name
        self.origin_desc = origin_desc
        self.schema = schema  # Reference to the DataSchema
        self.full_name = f"{self.schema.name}.{self.name}"
        if curr_desc:
            self.curr_desc = curr_desc
            self.curr_desc_stat = curr_desc_stat
        else:
            # 如果没有指定 curr_desc，则默认使用 origin_desc
            self.curr_desc = origin_desc
            self.curr_desc_stat = 'origin'
        self.fields = []

    def add_field(self, field: DataField):
        self.fields.append(field)

    def __repr__(self):
        return f"<DataTable(name='{self.full_name}', curr_desc='{self.curr_desc}')>"

    def to_dict(self, level='field'): # level: field, table, schema
        _d = {
            'name': self.name,
            'origin_desc': self.origin_desc,
            'curr_desc': self.curr_desc,
        }
        if level == 'field':
            _d['fields'] = [field.to_dict() for field in self.fields]
        return _d

    def to_dict_for_llm(self):
        # 如果有任何一个字段的 curr_desc 为空，则需要AI生成
        need_infer = 0
        for f in self.fields:
            if not f.curr_desc:
                need_infer = 1

        if need_infer:
            return {
                'name': self.name,
                'full_name': self.full_name,
                'curr_desc': self.curr_desc,
                'fields': [field.to_dict_for_llm() for field in self.fields]
            }
        else:
            return {}


class DataSchema(DataBaseObject):

    _save_in_db_properties = ['name', 'origin_desc', 'curr_desc',
                              'curr_desc_stat', 'curr_desc_stat']

    def __init__(self, name, metadata, origin_desc=None,
                 curr_desc=None, curr_desc_stat=None, **kwargs):
        self.name = name
        self.metadata = metadata  # Reference to the MetaData
        self.origin_desc = origin_desc
        if curr_desc:
            self.curr_desc = curr_desc
            self.curr_desc_stat = curr_desc_stat
        else:
            self.curr_desc = origin_desc
            self.curr_desc_stat = 'origin'
        self.tables = []

    def add_table(self, table: DataTable):
        self.tables.append(table)

    def __repr__(self):
        return f"<Schema: {self.name}>"

    def to_dict(self, level='field'):  # level: field, table, schema
        _d = {
            'name': self.name,
            'origin_desc': self.origin_desc,
            'curr_desc': self.curr_desc,
        }
        if level in ('table', 'field'):
            _d['tables'] = [table.to_dict(level) for table in self.tables]
        return _d

    def to_dict_for_llm(self):
        # if table.to_dict_for_llm() is empty, it will be ignored
        need_infer_tables = [table.to_dict_for_llm() for table in self.tables
                             if table.to_dict_for_llm()]
        if need_infer_tables or (not self.curr_desc):
            return {
                'name': self.name,
                'curr_desc': self.curr_desc,
                'tables': need_infer_tables
            }
        else:
            return {}


class MetaData(DataBaseObject):
    def __init__(self, name, datasource_id=''):
        self.name = name
        self.datasource_id = datasource_id
        self.schemas = []

    def add_schema(self, schema: DataSchema):
        self.schemas.append(schema)

    @classmethod
    def load_from_dict(cls, data: dict):
        """
        Load metadata from a dictionary structure.
        The expected format is:
        {
            'name': 'metadata_name',
            'datasource_id': '',
            'schemas': [
                {
                    'name': 'schema_name',
                    'tables': [
                        {
                            'name': 'table_name',
                            'fields': [
                                {
                                    'name': 'field_name',
                                    'origin_desc': 'original description',
                                    'related_field': 'schema2.table2.field2'
                                    ...
                                },
                                ...
                            ],
                            ...
                        },
                        ...
                    ],
                    ...
                },
                ...
            ]
        }
        """
        # 临时字典，用于存储字段引用
        field_refs = {}
        metadata = cls(data.get('name'), data.get('datasource_id'))
        # 首先，创建所有的 schema、table 和 field，但不设置 related_field
        for schema_data in data.get('schemas', []):
            schema = DataSchema(
                name=schema_data.get('name', ''),
                metadata=metadata,
                origin_desc=schema_data.get('origin_desc'),
                curr_desc=schema_data.get('curr_desc'),
                curr_desc_stat=schema_data.get('curr_desc_stat')
            )

            for table_data in schema_data.get('tables', []):
                table = DataTable(
                    name=table_data.get('name', ''),
                    schema=schema,
                    origin_desc=table_data.get('origin_desc'),
                    curr_desc=table_data.get('curr_desc'),
                    curr_desc_stat=table_data.get('curr_desc_stat')
                )

                for field_data in table_data.get('fields', []):
                    field = DataField(
                        name=field_data.get('name', ''),
                        table=table,
                        origin_desc=field_data.get('origin_desc'),
                        curr_desc=field_data.get('curr_desc'),
                        curr_desc_stat=field_data.get('curr_desc_stat'),
                    )
                    table.add_field(field)
                    # 创建一个唯一键来标识每个字段
                    field_key = f"{schema.name}.{table.name}.{field.name}"
                    field_refs[field_key] = field

                schema.add_table(table)

            metadata.add_schema(schema)

        # 现在，使用 field_refs 字典来设置 related_field 属性
        for schema_data in data.get('schemas', []):
            for table_data in schema_data.get('tables', []):
                for field_data in table_data.get('fields', []):
                    field_key = f"{schema_data.get('name', '')}.{table_data.get('name', '')}.{field_data.get('name', '')}"
                    field = field_refs.get(field_key)
                    related_field_key = field_data.get('related_field')
                    if related_field_key and related_field_key in field_refs:
                        # 设置相关字段的引用
                        field.set_related_field(field_refs[related_field_key])
        return metadata

    def __repr__(self):
        return f"{self.datasource_id} {self.summary} \n\n{self.to_table()}"

    def to_dict(self, level='field'):  # level: field, table, schema
        return {
            'name': self.name,
            'datasource_id': self.datasource_id,
            'schemas': [schema.to_dict(level) for schema in self.schemas]
        }

    def to_dict_for_llm(self):
        return {
            'name': self.name,
            'datasource_id': self.datasource_id,
            'schemas': [schema.to_dict_for_llm() for schema
                        in self.schemas if schema.to_dict_for_llm()]
        }

    @property
    def summary(self):
        """
        Summarize the metadata。只有Schema和Table给出前10条 item，Field不给出。
        Like this:
            共有：1 Schema (public), 1 Table (users), 2 Fields.
        """
        summary = f"共有："

        # Summarizing schemas
        schema_count = len(self.schemas)
        if schema_count <= 1:
            summary += f"{schema_count} Schema ("
        else:
            summary += f"{schema_count} Schemas ("
        for i, schema in enumerate(self.schemas[:10]):
            summary += schema.name
            if i < min(9, schema_count - 1):  # Add comma if not the last item
                summary += ","
        if schema_count > 10:
            summary += "..."
        summary += "), "

        # Summarizing tables and fields
        total_tables = 0
        total_fields = 0
        table_names = []

        for schema in self.schemas:
            total_tables += len(schema.tables)
            for table in schema.tables:
                total_fields += len(table.fields)
                if len(table_names) <= 5:
                    table_names.append(table.full_name)

        # Formatting tables list
        table_list = ",".join(table_names)
        if len(table_names) > 5:
            table_list += "..."

        if total_tables <= 1:
            summary += f"{total_tables} Table ({table_list}), "
        else:
            summary += f"{total_tables} Tables ({table_list}), "
        if total_fields <= 1:
            summary += f"{total_fields} Field."
        else:
            summary += f"{total_fields} Fields."
        return summary

    def get_field_by_full_name(self, full_name):
        """
        根据字段的完整名称来查找字段对象。
        完整名称格式为 "schema_name.table_name.field_name"
        """
        schema_name, table_name, field_name = full_name.split('.')
        for schema in self.schemas:
            if schema.name == schema_name:
                for table in schema.tables:
                    if table.name == table_name:
                        for field in table.fields:
                            if field.name == field_name:
                                return field
        return None

    def to_table(self, level='field'):  # level: field, table, schema
        data = []
        for schema in self.schemas:
            schema_desc = schema.name
            schema_desc += f"({schema.curr_desc})" if schema.curr_desc else ""
            if level == 'schema':
                _s = {
                    'Schemas': schema_desc,
                }
                data.append(_s)
            elif level in ('table', 'field'):
                for table in schema.tables:
                    table_desc = table.name
                    table_desc += f"({table.curr_desc})" if table.curr_desc else ""
                    _t = {
                        'Schemas': schema_desc,
                        'Tables': table_desc,
                    }
                    if level == 'field':
                        known_f = len([f for f in table.fields if f.curr_desc])
                        all_f = len(table.fields)
                        fields = f"{known_f}/{all_f}"
                        _t['Fields(known/all)'] = fields
                    data.append(_t)
            else:
                raise ValueError(f"Invalid level: {level}")
        return tabulate(data, headers="keys", tablefmt="plain")


from rmbclient import RMB
from unittest import TestCase

class TestDataResource(TestCase):
    def test_clear(self):

        # 初始化 IntelligentDataCortex 实例
        data = RMB(token="token1", debug=True)
        data.test_clear_chat()



from rmbcommon.models.datasource import DataSourceCore
from rmbcommon.models.meta import MetaData, DataField, DataTable, DataSchema
from rmbcommon.models.chat import ChatCore, MessageCore, RunCore
from rmbcommon.models.bi import StrucQuery, QueryResult, BIAnswer

__all__ = [
    'MetaData',
    'DataField',
    'DataTable',
    'DataSchema',
    'DataSourceCore',
    'ChatCore',
    'MessageCore',
    'RunCore',
    'StrucQuery',
    'QueryResult',
    'BIAnswer',
]


import argparse
import sys
import os
sys.path.append(os.path.dirname(os.path.dirname(__file__)))

def main():
    # 设置命令行参数解析
    parser = argparse.ArgumentParser(description="Interactive CLI for RMB client.")
    parser.add_argument('-a', '--api_url',
                        type=str,
                        default='http://127.0.0.1:5000',
                        help='The API URL for the RMB client.')
    parser.add_argument('-t', '--token',
                        type=str,
                        default='token1',
                        help='The token for authentication.')

    args = parser.parse_args()

    # 导入 RMB 类
    from rmbclient import RMB
    rmb = RMB(token=args.token, api_url=args.api_url)
    print(f"\n-- RMB 客户端({rmb.version})初始化完成！")
    print("-- 连接服务器：", args.api_url)
    print("-- 您可以使用 'rmb' 来访问RMB，比如：通过 'rmb.datasources' 来查询数据源列表")
    print("   完整的使用方法，请参考帮助文档：https://pypi.org/project/rmb-client/\n")

    try:
        # 尝试导入 IPython
        from IPython import start_ipython
        start_ipython(argv=[], user_ns={'rmb': rmb})
    except ImportError:
        # 如果 IPython 未安装，使用标准 Python shell
        import code
        code.interact(local=locals())


if __name__ == "__main__":
    main()



import logging
import os
import sys
from logging.handlers import RotatingFileHandler


# Configuration
LOG_DIR = os.path.join(os.path.expanduser('~'), '.rmb')

# Create directory if it doesn't exist
os.makedirs(LOG_DIR, exist_ok=True)

formatter = logging.Formatter('%(asctime)s - %(levelname)s - [%(filename)s:%(lineno)d] - %(message)s')
simple_formatter = logging.Formatter('%(message)s')

# Common configurations for both loggers
log_file_path = os.path.join(LOG_DIR, 'sdk.log')
file_handler = RotatingFileHandler(log_file_path, maxBytes=1024 * 1024, backupCount=3)
file_handler.setFormatter(formatter)

console_handler = logging.StreamHandler(sys.stdout)
console_handler.setFormatter(simple_formatter)

# Logger which writes to file only
log = logging.getLogger('sdklog')

log.setLevel(logging.DEBUG)
log.addHandler(console_handler)
log.addHandler(file_handler)







from rmbcommon.models.base import BaseCoreModel
from rmbcommon.tools import format_time_ago


class ChatCore(BaseCoreModel):
    __init_dict_keys__ = ['id', 'datasource_ids', 'created']

    def __repr__(self):
        return f"<Chat {self.id} [{format_time_ago(self.created)}]>"


class MessageCore(BaseCoreModel):

    # role: human | ai
    __init_dict_keys__ = ['id', 'chat_id', 'created', 'role', 'content']

    def __repr__(self):
        return f"<Message {self.id}: {self.role}: {self.content} [{format_time_ago(self.created)}]>"


class RunCore(BaseCoreModel):
    # status: running | finished | failed | canceled
    __init_dict_keys__ = ['id', 'chat_id', 'created', 'status', 'steps']

    def __repr__(self):
        return f"<ChatRun {self.id} [{format_time_ago(self.created)}]>"



from setuptools import setup, find_packages
from rmbcommon.version import VERSION

with open("README.md") as f:
    long_description = f.read()

with open("requirements_client.txt") as f:
    requirements = f.readlines()
    install_requires = [r.strip() for r in requirements if r.strip()]


setup(
    name='rmb-client',
    version=VERSION,
    description='RMB SDK.',
    url='https://github.com/DataMini/rmb',
    author='lele',
    packages=find_packages(
        include=["rmbclient",
                 "rmbclient.*",
                 "rmbcommon",
                 "rmbcommon.*"
                 ]  # 包含 rmbclient 包和 rmbcommon
    ),
    long_description=long_description,
    long_description_content_type="text/markdown",
    install_requires=install_requires,
    entry_points={
        'console_scripts': [
            'rmb-client = rmbclient.cli:main',
        ]
    },
)
